==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/DefaultL3VpnSvc.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc.Sites;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc.VpnServices;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of l3VpnSvc.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultL3VpnSvc extends InnerModelObject implements L3VpnSvc {
    protected VpnServices vpnServices;
    protected Sites sites;

    @Override
    public VpnServices vpnServices() {
        return vpnServices;
    }

    @Override
    public Sites sites() {
        return sites;
    }

    @Override
    public void vpnServices(VpnServices vpnServices) {
        this.vpnServices = vpnServices;
    }

    @Override
    public void sites(Sites sites) {
        this.sites = sites;
    }

    @Override
    public int hashCode() {
        return Objects.hash(vpnServices, sites);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultL3VpnSvc) {
            DefaultL3VpnSvc other = (DefaultL3VpnSvc) obj;
            return
                Objects.equals(vpnServices, other.vpnServices) &&
                Objects.equals(sites, other.sites);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("vpnServices=" + vpnServices)
            .add("sites=" + sites)
            .toString();
    }


    /**
     * Creates an instance of defaultL3VpnSvc.
     */
    public DefaultL3VpnSvc() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/DefaultL3VpnSvc.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc.Sites;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc.VpnServices;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of l3VpnSvc.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultL3VpnSvc extends InnerModelObject implements L3VpnSvc {
    protected VpnServices vpnServices;
    protected Sites sites;

    @Override
    public VpnServices vpnServices() {
        return vpnServices;
    }

    @Override
    public Sites sites() {
        return sites;
    }

    @Override
    public void vpnServices(VpnServices vpnServices) {
        this.vpnServices = vpnServices;
    }

    @Override
    public void sites(Sites sites) {
        this.sites = sites;
    }

    @Override
    public int hashCode() {
        return Objects.hash(vpnServices, sites);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultL3VpnSvc) {
            DefaultL3VpnSvc other = (DefaultL3VpnSvc) obj;
            return
                Objects.deepEquals(vpnServices, other.vpnServices) &&
                Objects.deepEquals(sites, other.sites);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("vpnServices=" + vpnServices)
            .add("sites=" + sites)
            .toString();
    }


    /**
     * Creates an instance of defaultL3VpnSvc.
     */
    public DefaultL3VpnSvc() {
    }

}
